package codicefiscaleproject01;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.HashMap;

public class CodiceFiscaleCalcolatore extends JFrame implements ActionListener {
    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private JTextField campoNome, campoCognome, campoData, campoComune;
    private JComboBox<String> comboSesso;
    private JTextField campoRisultato;
    private JButton calcolaButton;
    
    // Mappa dei comuni con codici fittizi per semplicità
    private HashMap<String, String> comuneCodici = new HashMap<>();

    public CodiceFiscaleCalcolatore() {
        setTitle("Calcolatore Codice Fiscale");
        setSize(400, 300);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);

        // Creazione della UI
        JPanel pannello = new JPanel(new GridLayout(6, 2, 5, 5));

        pannello.add(new JLabel("Nome:"));
        campoNome = new JTextField();
        pannello.add(campoNome);

        pannello.add(new JLabel("Cognome:"));
        campoCognome = new JTextField();
        pannello.add(campoCognome);

        pannello.add(new JLabel("Data di Nascita (GG/MM/AAAA):"));
        campoData = new JTextField();
        pannello.add(campoData);

        pannello.add(new JLabel("Sesso:"));
        comboSesso = new JComboBox<>(new String[]{"M", "F"});
        pannello.add(comboSesso);

        pannello.add(new JLabel("Comune di Nascita:"));
        campoComune = new JTextField();
        pannello.add(campoComune);

        calcolaButton = new JButton("Calcola Codice Fiscale");
        calcolaButton.addActionListener(this);
        pannello.add(calcolaButton);

        campoRisultato = new JTextField();
        campoRisultato.setEditable(false);
        pannello.add(new JLabel("Codice Fiscale:"));
        pannello.add(campoRisultato);

        add(pannello);

        // Aggiunta dei codici fittizi di alcuni comuni
        comuneCodici.put("ROMA", "H501");
        comuneCodici.put("MILANO", "F205");
        comuneCodici.put("NAPOLI", "F839");
        comuneCodici.put("FROSINONE", "D810");
        comuneCodici.put("ALATRI", "A123");
    }

    // Metodo per calcolare il codice fiscale
    private String calcolaCodiceFiscale(String nome, String cognome, String dataNascita, String sesso, String comune) {
        String codiceCognome = estraiConsonanti(cognome).toUpperCase();
        String codiceNome = estraiConsonanti(nome).toUpperCase();

        // Estrazione della data di nascita
        String[] partiData = dataNascita.split("/");
        String anno = partiData[2].substring(2);
        String mese = codiceMese(partiData[1]);
        String giorno = calcolaGiorno(Integer.parseInt(partiData[0]), sesso);

        // Codice del comune
        String codiceComune = comuneCodici.getOrDefault(comune.toUpperCase(), "XXXX");

        // Composizione finale del codice fiscale
        return (codiceCognome + codiceNome + anno + mese + giorno + codiceComune + "XXX").substring(0, 16);
    }

    // Estrae le consonanti del nome o cognome
    private String estraiConsonanti(String s) {
        StringBuilder consonanti = new StringBuilder();
        for (char c : s.toCharArray()) {
            if (isConsonante(c)) {
                consonanti.append(c);
            }
        }
        while (consonanti.length() < 3) {
            consonanti.append('X'); // Riempimento con X se mancano consonanti
        }
        return consonanti.substring(0, 3);
    }

    private boolean isConsonante(char c) {
        return "BCDFGHJKLMNPQRSTVWXYZ".indexOf(Character.toUpperCase(c)) != -1;
    }

    // Codice del mese in base al numero del mese
    private String codiceMese(String mese) {
        switch (mese) {
            case "01": return "A";
            case "02": return "B";
            case "03": return "C";
            case "04": return "D";
            case "05": return "E";
            case "06": return "H";
            case "07": return "L";
            case "08": return "M";
            case "09": return "P";
            case "10": return "R";
            case "11": return "S";
            case "12": return "T";
            default: return "X"; // Codice sconosciuto
        }
    }

    // Calcolo del giorno in base al sesso
    private String calcolaGiorno(int giorno, String sesso) {
        if (sesso.equals("F")) {
            giorno += 40;
        }
        return (giorno < 10) ? "0" + giorno : String.valueOf(giorno);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == calcolaButton) {
            String nome = campoNome.getText();
            String cognome = campoCognome.getText();
            String dataNascita = campoData.getText();
            String sesso = comboSesso.getSelectedItem().toString();
            String comune = campoComune.getText();
            
            String codiceFiscale = calcolaCodiceFiscale(nome, cognome, dataNascita, sesso, comune);
            campoRisultato.setText(codiceFiscale);
        }
    }

    public static void main(String[] args) {
        SwingUtilities.invokeLater(() -> {
            new CodiceFiscaleCalcolatore().setVisible(true);
        });
    }
}

