package gestionebancaproject04;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;

public class ContoCorrenteGUI extends JFrame implements ActionListener {
    /**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private double saldo = 0.0;
    private ArrayList<String> transazioni = new ArrayList<>();

    // Componenti della UI
    private JLabel labelSaldo;
    private JTextField campoImporto;
    private JButton bottoneDeposito, bottonePrelievo, bottoneMostraTransazioni;
    private JTextArea areaTransazioni;

    public ContoCorrenteGUI() {
        setTitle("Gestione Conto Corrente");
        setSize(400, 300);
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setLocationRelativeTo(null);

        // Layout principale
        JPanel pannello = new JPanel(new GridLayout(5, 1, 5, 5));

        // Mostrare saldo
        labelSaldo = new JLabel("Saldo attuale: € 0.00");
        pannello.add(labelSaldo);

        // Campo di input per importo
        JPanel pannelloImporto = new JPanel(new FlowLayout());
        pannelloImporto.add(new JLabel("Importo: "));
        campoImporto = new JTextField(10);
        pannelloImporto.add(campoImporto);
        pannello.add(pannelloImporto);

        // Pulsanti per deposito e prelievo
        JPanel pannelloBottoni = new JPanel(new FlowLayout());
        bottoneDeposito = new JButton("Deposita");
        bottoneDeposito.addActionListener(this);
        pannelloBottoni.add(bottoneDeposito);

        bottonePrelievo = new JButton("Preleva");
        bottonePrelievo.addActionListener(this);
        pannelloBottoni.add(bottonePrelievo);
        pannello.add(pannelloBottoni);

        // Pulsante per mostrare le transazioni
        bottoneMostraTransazioni = new JButton("Mostra Transazioni");
        bottoneMostraTransazioni.addActionListener(this);
        pannello.add(bottoneMostraTransazioni);

        // Area di testo per visualizzare le transazioni
        areaTransazioni = new JTextArea();
        areaTransazioni.setEditable(false);
        JScrollPane scrollPane = new JScrollPane(areaTransazioni);
        scrollPane.setPreferredSize(new Dimension(350, 100));
        pannello.add(scrollPane);

        add(pannello);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        String importoTesto = campoImporto.getText();
        try {
            double importo = Double.parseDouble(importoTesto);
            
            if (e.getSource() == bottoneDeposito) {
                effettuaDeposito(importo);
            } else if (e.getSource() == bottonePrelievo) {
                effettuaPrelievo(importo);
            } else if (e.getSource() == bottoneMostraTransazioni) {
                mostraTransazioni();
            }
        } catch (NumberFormatException ex) {
            JOptionPane.showMessageDialog(this, "Inserisci un importo valido", "Errore", JOptionPane.ERROR_MESSAGE);
        }
    }

    // Funzione per effettuare un deposito
    private void effettuaDeposito(double importo) {
        if (importo <= 0) {
            JOptionPane.showMessageDialog(this, "L'importo deve essere positivo", "Errore", JOptionPane.ERROR_MESSAGE);
            return;
        }
        saldo += importo;
        transazioni.add("Deposito: € " + String.format("%.2f", importo));
        aggiornaSaldo();
        campoImporto.setText("");
    }

    // Funzione per effettuare un prelievo
    private void effettuaPrelievo(double importo) {
        if (importo <= 0) {
            JOptionPane.showMessageDialog(this, "L'importo deve essere positivo", "Errore", JOptionPane.ERROR_MESSAGE);
            return;
        }
        if (importo > saldo) {
            JOptionPane.showMessageDialog(this, "Saldo insufficiente", "Errore", JOptionPane.ERROR_MESSAGE);
            return;
        }
        saldo -= importo;
        transazioni.add("Prelievo: € " + String.format("%.2f", importo));
        aggiornaSaldo();
        campoImporto.setText("");
    }

    // Funzione per aggiornare la visualizzazione del saldo
    private void aggiornaSaldo() {
        labelSaldo.setText("Saldo attuale: € " + String.format("%.2f", saldo));
    }

    // Funzione per mostrare le transazioni
    private void mostraTransazioni() {
        StringBuilder transazioniTesto = new StringBuilder();
        for (String transazione : transazioni) {
            transazioniTesto.append(transazione).append("\n");
        }
        areaTransazioni.setText(transazioniTesto.toString());
    }

    public static void main(String[] args) {

    }
}

